<template>
    <div class="system-role-container">
        <el-card shadow="hover">
            <div class="system-user-search mb15">
                <div class="basic-line">
                    <span>排查作业类型：</span>
                    <el-select class="input-box" v-model="workData.params.checkWorkType" placeholder="排查作业类型" filterable clearable>
                        <el-option v-for="item in checkWorkTypeList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>排查作业状态：</span>
                    <el-select class="input-box" v-model="workData.params.checkWorkStatus" placeholder="排查作业状态" filterable clearable>
                        <el-option v-for="item in checkWorkStatusList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>排查作业名称：</span>
                    <el-input class="input-box" v-model="workData.params.checkWorkName" placeholder="排查作业名称" clearable> </el-input>
                </div>

                <el-button size="default" type="primary" class="ml10" v-throttle @click="handleSearch">
                    <el-icon>
                        <ele-Search />
                    </el-icon>
                    查询
                </el-button>
                <el-button size="default" type="success" class="ml10" @click="onOpenDialogRef('新增', '')">
                    <el-icon>
                        <ele-FolderAdd />
                    </el-icon>
                    新增排查任务
                </el-button>
            </div>
            <el-table :data="workData.data" style="width: 100%">
                <el-table-column type="index" label="序号" width="60" />
                <el-table-column prop="checkWorkName" label="排查名称" show-overflow-tooltip></el-table-column>
                <el-table-column prop="checkWorkType" label="排查类型" show-overflow-tooltip>
                    <template #default="scope">
                        {{ parseNumber(scope.row.checkWorkType, '排查类型') }}
                    </template>
                </el-table-column>
                <el-table-column prop="taskUnitName" label="任务单元" show-overflow-tooltip></el-table-column>
                <el-table-column prop="execUserName" label="执行人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="checkCycle" label="排查周期" show-overflow-tooltip>
                    <template #default="scope">
                        <span>
                            {{ scope.row.checkCycle }}
                        </span>
                        <span>
                            {{ parseNumber(scope.row.checkWorkType, '排查周期') }}
                        </span>
                    </template>
                </el-table-column>
                <el-table-column prop="validTime" label="排查周期" show-overflow-tooltip>
                    <template #default="scope">
                        <span>
                            {{ scope.row.validTime }}
                        </span>
                        <span>
                            {{ parseNumber(scope.row.validTimeUnit, '排查周期') }}
                        </span>
                    </template>
                </el-table-column>
                <el-table-column prop="createByUserName" label="创建人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtCreate" label="创建时间" show-overflow-tooltip></el-table-column>
                <el-table-column prop="lastEditUserName" label="最后修改人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtModitify" label="最后修改时间" show-overflow-tooltip></el-table-column>
                <el-table-column label="操作" width="200" align="center">
                    <template #default="scope">
                        <el-button size="small" text type="primary" :icon="View" @click="onOpenDialogRef('查看', scope.row)">查看</el-button>
                        <el-button size="small" text type="primary" :icon="Edit" @click="onOpenDialogRef('修改', scope.row)">修改</el-button>
                        <el-button size="small" text type="danger" :icon="Delete" @click="onDelWork(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="workData.params.pageIndex" background v-model:page-size="workData.params.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="workData.total" class="page-position"> </el-pagination>
            <br />
            <br />
        </el-card>
        <workDialog ref="workDialogRef" @refreshWork="initWorkTableData" />
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, onMounted, ref, defineComponent } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import workDialog from './components/workDialog.vue';
import { workApi } from '/@/api/doublePreventSystem/work/index.ts';
import { departmentApi } from '/@/api/systemManage/department';
import { Edit, Delete, View } from '@element-plus/icons-vue';
import { checkUnitApi } from '/@/api/doublePreventSystem/checkUnit';

// 定义接口来定义对象的类型
interface TableData {
    roleName: string;
    roleSign: string;
    describe: string;
    sort: number;
    status: boolean;
    createTime: string;
}
interface TableDataState {
    workData: {
        data: Array<TableData>;
        total: number;
        loading: boolean;
        params: {
            pageIndex: number;
            pageSize: number;
            checkWorkType: number | null;
            checkWorkStatus: number | null;
            checkWorkName: string | null;
        };
    };
    timeType: Array<levelListState>;
    taskUnitList: Array<taskUnit>;
    departmentList: Array<DepartmentState>;
    checkWorkTypeList: Array<levelListState>;
    checkWorkStatusList: Array<levelListState>;
}
interface levelListState {
    id: number;
    name: string;
}
interface DepartmentState {}
interface taskUnit {
    id: number;
    taskUnitName: string;
}

export default defineComponent({
    name: 'work',
    components: { workDialog, Edit, Delete, View },
    setup() {
        const workDialogRef = ref();
        const state = reactive<TableDataState>({
            workData: {
                data: [],
                total: 0,
                loading: false,
                params: {
                    pageIndex: 1,
                    pageSize: 10,
                    checkWorkType: null,
                    checkWorkStatus: null,
                    checkWorkName: null
                }
            },
            taskUnitList: [],
            departmentList: [],
            checkWorkTypeList: [
                { id: 1, name: '日常作业' },
                { id: 2, name: '周期作业' }
            ],
            checkWorkStatusList: [
                { id: 1, name: '开启' },
                { id: 2, name: '关闭' },
                { id: 2, name: '过期' }
            ],
            timeType: [
                { id: 1, name: '分' },
                { id: 2, name: '小时' },
                { id: 3, name: '日' },
                { id: 4, name: '月' },
                { id: 5, name: '年' }
            ]
        });
        // 初始化表格数据
        const initWorkTableData = async () => {
            let res = await workApi().getWorkList(state.workData.params);
            if (res.data.code === '200') {
                state.workData.data = res.data.data;
                state.workData.total = res.data.count;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        //获取部门列表
        const getDepartmentData = async () => {
            let res = await departmentApi().getDepartmentList();
            if (res.data.code === '200') {
                state.departmentList = res.data.data;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        const getCheckUnitData = async () => {
            let res = await checkUnitApi().getAllCheckUnitList();
            if (res.data.code === '200') {
                state.taskUnitList = res.data.data;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        // 打开生产装置弹窗
        const onOpenDialogRef = (type: string, value: any) => {
            workDialogRef.value.openWorkDialog(type, value, state.departmentList, state.checkWorkTypeList, state.taskUnitList);
        };
        // 删除角色
        const onDelWork = (row: any) => {
            ElMessageBox.confirm(`此操作将永久删除该条生产装置：“${row.produceDeviceName}”，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await workApi().deleteWork({ id: row.id });
                    if (res.data.code === '200') {
                        ElMessage({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await initWorkTableData();
                    } else {
                        ElMessage({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                })
                .catch(() => {});
        };

        const parseNumber = (value: string | number, type: string) => {
            if (type === '排查类型') {
                return state.checkWorkTypeList.find((item) => item.id === value)?.name;
            } else if (type === '排查周期') {
                return state.timeType.find((item) => item.id == value)?.name;
            }
        };

        const handleSearch = () => {
            initWorkTableData();
        };
        // 分页改变
        const onHandleSizeChange = (val: number) => {
            state.workData.params.pageSize = val;
            initWorkTableData();
        };
        // 分页改变
        const onHandleCurrentChange = (val: number) => {
            state.workData.params.pageIndex = val;
            initWorkTableData();
        };
        // 页面加载时
        onMounted(() => {
            initWorkTableData();
            getCheckUnitData();
            getDepartmentData();
        });

        return {
            Edit,
            Delete,
            View,
            handleSearch,
            onOpenDialogRef,
            onHandleSizeChange,
            onDelWork,
            parseNumber,
            onHandleCurrentChange,
            workDialog,
            workDialogRef,
            initWorkTableData,
            ...toRefs(state)
        };
    }
});
</script>

<style scoped></style>
